@@ -45,9 +45,8 @@ class ConfigurationStore {
 			return; // no persistent store
 
 		store.mkdir();
-		File[] configurationFiles = store.listFiles();
-		for (int i = 0; i < configurationFiles.length; ++i) {
-			String configurationFileName = configurationFiles[i].getName();
+		for (File configurationFile : store.listFiles()) {
+			String configurationFileName = configurationFile.getName();
 			if (!configurationFileName.endsWith(CFG_EXT))
 				continue;
 
@@ -55,7 +54,7 @@ class ConfigurationStore {
 			ObjectInputStream ois = null;
 			boolean deleteFile = false;
 			try {
-				ris = new ReliableFileInputStream(configurationFiles[i]);
+				ris = new ReliableFileInputStream(configurationFile);
 				ois = new ObjectInputStream(ris);
 				@SuppressWarnings("unchecked")
 				Dictionary<String, Object> dictionary = (Dictionary<String, Object>) ois.readObject();
@@ -67,7 +66,7 @@ class ConfigurationStore {
 						dictionary.remove(ConfigurationAdmin.SERVICE_BUNDLELOCATION);
 					}
 				}
-				ConfigurationImpl config = new ConfigurationImpl(configurationAdminFactory, this, dictionary, configurationFiles[i]);
+				ConfigurationImpl config = new ConfigurationImpl(configurationAdminFactory, this, dictionary, configurationFile);
 				configurations.put(config.getPid(), config);
 			} catch (IOException e) {
 				String message = e.getMessage();
@@ -94,8 +93,8 @@ class ConfigurationStore {
 				}
 			}
 			if (deleteFile) {
-				ReliableFile.delete(configurationFiles[i]);
-				configurationFiles[i].delete();
+				ReliableFile.delete(configurationFile);
+				configurationFile.delete();
 			}
 		}
 	}
