@@ -16,7 +16,6 @@ package org.eclipse.equinox.http.servlet.tests.util;
 
 import java.io.IOException;
 
-import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
@@ -31,7 +30,7 @@ public class BaseChangeSessionIdServlet extends BaseServlet {
 	@Override
 	protected void service(
 			HttpServletRequest request, HttpServletResponse response)
-		throws ServletException, IOException {
+		throws IOException {
 
 		request.getSession(true);
 
