@@ -17,7 +17,6 @@ package org.eclipse.equinox.http.servlet.tests.util;
 import java.io.IOException;
 import java.io.PrintWriter;
 
-import javax.servlet.ServletException;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -30,7 +29,7 @@ public class BufferedServlet extends HttpServlet {
 	@Override
 	protected void service(
 			HttpServletRequest request, HttpServletResponse response)
-		throws ServletException, IOException {
+		throws IOException {
 
 		response.setContentType( "text/html" );
 		response.setBufferSize(value.length);
