@@ -16,7 +16,7 @@ package org.eclipse.equinox.internal.security.ui.wizard;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.security.cert.*;
-import java.util.*;
+import java.util.ArrayList;
 import java.util.List;
 import org.eclipse.equinox.internal.security.ui.SecurityUIMsg;
 import org.eclipse.jface.wizard.WizardPage;
@@ -47,6 +47,7 @@ public class CertificateImportCertSelectPage extends WizardPage implements Liste
 		setDescription(SecurityUIMsg.WIZARD_SELECT_CERT_FROM_DROP_DOWN);
 	}
 
+	@Override
 	public void createControl(Composite parent) {
 		Composite certSelectComposite = new Composite(parent, SWT.NONE);
 		setControl(certSelectComposite);
@@ -79,10 +80,9 @@ public class CertificateImportCertSelectPage extends WizardPage implements Liste
 
 		try {
 			certList = new ArrayList<>();
-			Collection<? extends Certificate> collection = certFact.generateCertificates(new FileInputStream(certImportWizard.selectedImportFile));
 			// For a set or list
-			for (Iterator<? extends Certificate> it = collection.iterator(); it.hasNext();) {
-				certList.add(it.next());
+			for (Certificate certificate : certFact.generateCertificates(new FileInputStream(certImportWizard.selectedImportFile))) {
+				certList.add(certificate);
 			}
 
 		} catch (CertificateException e) {
@@ -91,8 +91,8 @@ public class CertificateImportCertSelectPage extends WizardPage implements Liste
 			setErrorMessage(e.getMessage());
 		}
 
-		for (int i = 0; i < certList.size(); i++) {
-			X509Certificate x509Cert = (X509Certificate) certList.get(i);
+		for (Certificate certificate : certList) {
+			X509Certificate x509Cert = (X509Certificate) certificate;
 			String subjectDN = x509Cert.getSubjectDN().getName();
 			certDropDown.add(subjectDN);
 		}
@@ -100,6 +100,7 @@ public class CertificateImportCertSelectPage extends WizardPage implements Liste
 
 	}
 
+	@Override
 	public void handleEvent(Event e) {
 		if (e.widget == certDropDown) {
 			// populate the preview with select cert info
@@ -123,6 +124,7 @@ public class CertificateImportCertSelectPage extends WizardPage implements Liste
 	/**
 	 * This methods get called before each page gets showed
 	 */
+	@Override
 	public void setVisible(boolean visible) {
 		if (visible)
 			populateDropDown();
@@ -130,6 +132,7 @@ public class CertificateImportCertSelectPage extends WizardPage implements Liste
 
 	}
 
+	@Override
 	public boolean canFlipToNextPage() {
 		return ((CertificateImportWizard) getWizard()).selectCert != null;
 	}
